@@ -17,15 +17,14 @@ array order is different from the stored array order (platform, encoding,
 language, number) to allow for easy manipulation of strings by number (which is
 what I guess most people will want to do).
 
-If C<$Font::TTF::Name::utf8> is set to 1, strings will be stored as UTF8 wherever
+By default, C<$Font::TTF::Name::utf8> is set to 1, and strings will be stored as UTF8 wherever
 possible. The method C<is_utf8> can be used to find out if a string in a particular
 platform and encoding will be returned as UTF8. Unicode strings are always
 converted if utf8 is requested. Otherwise, strings are stored according to platform:
 
-    ***WARNING NON-UTF8 is deprecated and utf8 strings will become the default***
+    ***WARNING NON-UTF8 is deprecated and utf8 strings has become the default***
 
-As of a later version, you will have to set <$Font::TTF::Name::utf8> to 0 to get
-old behaviour.
+You now have to set <$Font::TTF::Name::utf8> to 0 to get the old behaviour.
 
 =over 4
 
@@ -72,7 +71,8 @@ use Font::TTF::Table;
 use Font::TTF::Utils;
 @ISA = qw(Font::TTF::Table);
 
-if ($utf8)
+$utf8 = 1;
+
 {
     my ($count, $i);
     eval {require Compress::Zlib;};
@@ -180,7 +180,7 @@ sub out
     }
 
     $offset = 0;
-    @todo = (sort {$a->[0] <=> $b->[0] || $a->[1] <=> $b->[1] || $a->[2] <=> $a->[2]
+    @todo = (sort {$a->[0] <=> $b->[0] || $a->[1] <=> $b->[1] || $a->[2] <=> $b->[2]
             || $a->[3] <=> $b->[3]} @todo);
     foreach $todo (@todo)
     {
@@ -201,6 +201,64 @@ sub out
 }
 
 
+=head2 $t->XML_element($context, $depth, $key, $value)
+
+Outputs the string element in nice XML (which is all the table really!)
+
+=cut
+
+sub XML_element
+{
+    my ($self) = shift;
+    my ($context, $depth, $key, $value) = @_;
+    my ($fh) = $context->{'fh'};
+    my ($nid, $pid, $eid, $lid);
+
+    return $self->SUPER::XML_element(@_) unless ($key eq 'strings');
+
+    foreach $nid (0 .. $#{$self->{'strings'}})
+    {
+        next unless ref($self->{'strings'}[$nid]);
+#        $fh->print("$depth<strings id='$nid'>\n");
+        foreach $pid (0 .. $#{$self->{'strings'}[$nid]})
+        {
+            foreach $eid (0 .. $#{$self->{'strings'}[$nid][$pid]})
+            {
+                foreach $lid (sort {$a <=> $b} keys %{$self->{'strings'}[$nid][$pid][$eid]})
+                {
+                    $fh->printf("%s<string id='%s' platform='%s' encoding='%s' language='%s'>\n%s%s%s\n%s</string>\n",
+                            $depth, $nid, $pid, $eid, $lid, $depth,
+                            $context->{'indent'}, $self->{'strings'}[$nid][$pid][$eid]{$lid}, $depth);
+                }
+            }
+        }
+#        $fh->print("$depth</strings>\n");
+    }
+    $self;
+}
+
+
+=head2 $t->XML_end($context, $tag, %attrs)
+
+Store strings in the right place
+
+=cut
+
+sub XML_end
+{
+    my ($self) = shift;
+    my ($context, $tag, %attrs) = @_;
+
+    if ($tag eq 'string')
+    {
+        $self->{'strings'}[$attrs{'id'}][$attrs{'platform'}][$attrs{'encoding'}]{$attrs{'language'}}
+            = $context->{'text'};
+        return $context;
+    }
+    else
+    { return $self->SUPER::XML_end(@_); }
+}
+
 =head2 is_utf8($pid, $eid)
 
 Returns whether a string of a given platform and encoding is going to be in UTF8
@@ -228,7 +286,7 @@ sub find_name
     my ($self, $nid) = @_;
     my ($res, $pid, $eid, $lid, $look, $k);
 
-    my (@lookup) = ([3, 1, 1033], [3, 1, -1], [2, 1, -1], [2, 2, -1], [2, 0, -1],
+    my (@lookup) = ([3, 1, 1033], [3, 1, -1], [3, 0, 1033], [3, 0, -1], [2, 1, -1], [2, 2, -1], [2, 0, -1],
                     [0, 0, 0], [1, 0, 0]);
     foreach $look (@lookup)
     {
